@@ -16,7 +16,7 @@
 #'@examples \dontrun{
 #' w <- workflow(UKAnophelesPlumbeus,
 #'               UKAir,
-#'               OneHundredBackground, 
+#'               Background(n = 70), 
 #'               LogisticRegression,
 #'               PrintMap)
 #'
@@ -24,8 +24,6 @@
 #'                      output = PrintMap)
 #'}
 
-
-
 ChangeWorkflow <- function(workflow, occurrence = NULL, covariate = NULL, process = NULL, 
                     model = NULL, output = NULL, forceReproducible = NULL) {
 
@@ -184,10 +182,14 @@ ChangeWorkflow <- function(workflow, occurrence = NULL, covariate = NULL, proces
   
   if (from <= 1) {
     tryCatch({
-      occurrence.output <- lapply(occurrenceName, function(x) do.call(x$func, x$paras))
+      occurrence.output <- lapply(occurrenceName, FUN = DoOccurrenceModule, e)
       # Then bind together if the occurrence modules were chained
       if (identical(attr(occurrence.module, 'chain'), TRUE)){
         occurrence.output <- list(do.call(rbind, occurrence.output))
+        attr(occurrence.output[[1]], 'call_path') <- list(occurrence = paste('Chain(',
+                                                                             paste(lapply(occurrenceName, function(x) x$module),
+                                                                                   collapse = ', '),
+                                                                             ')', sep = ''))
       }
       output$occurrence.output <- occurrence.output
     },  
@@ -202,9 +204,13 @@ ChangeWorkflow <- function(workflow, occurrence = NULL, covariate = NULL, proces
 
   if (from <= 2) {
     tryCatch({
-      covariate.output <- lapply(covariateName, function(x) do.call(x$func, x$paras))
+      covariate.output <- lapply(covariateName, FUN = DoCovariateModule, e)
       if (identical(attr(covariate.module, 'chain'), TRUE)){
         covariate.output <- list(do.call(raster::stack, covariate.output))
+        attr(covariate.output[[1]], 'call_path') <- list(covariate = paste('Chain(',
+                                                                           paste(lapply(covariateName, function(x) x$module),
+                                                                                 collapse = ', '),
+                                                                           ')', sep = ''))
       }
       output$covariate.output <- covariate.output
     },  
@@ -271,7 +277,7 @@ ChangeWorkflow <- function(workflow, occurrence = NULL, covariate = NULL, proces
   if (from <= 5) {
     tryCatch({
       output.output <- DoOutputModules(output.module, outputName, 
-                         covariate.module, covariate.output, model.output, e)
+                         process.module, process.output, model.output, e)
       output$report <- output.output
     },  
       error = function(cond){
@@ -282,10 +288,4 @@ ChangeWorkflow <- function(workflow, occurrence = NULL, covariate = NULL, proces
     output.output <- workflow$report
     output$report <- output.output
   }
-
-
 }
-
-
-
-
