@@ -1,10 +1,10 @@
-context('Testing call_path')
+context('call_path')
 
 test_that('Test call_path in a large number of variations', {
   
   skip_on_cran()
   
-  CP_work <- workflow(occurrence = list(UKAnophelesPlumbeus, AnophelesPlumbeus),
+  CP_work <- workflow(occurrence = list(UKAnophelesPlumbeus, NaiveRandomPresence),
                       covariate  = UKAir,
                       process    = Background(n=70),
                       model      = RandomForest,
@@ -13,14 +13,14 @@ test_that('Test call_path in a large number of variations', {
   expect_equal(attr(Occurrence(CP_work)[[1]], 'call_path'),
                structure(list(covariate = "UKAnophelesPlumbeus"), .Names = "occurrence"))
   expect_equal(attr(Occurrence(CP_work)[[2]], 'call_path'),
-               structure(list(covariate = "AnophelesPlumbeus"), .Names = "occurrence"))
+               structure(list(covariate = "NaiveRandomPresence"), .Names = "occurrence"))
   expect_equal(attr(Covariate(CP_work), 'call_path'),
                structure(list(covariate = "UKAir"), .Names = "covariate"))
   expect_equal(attr(Process(CP_work)[[1]], 'call_path'),
                structure(list(occurrence = "UKAnophelesPlumbeus", covariate = "UKAir", process = "Background"),
                          .Names = c("occurrence", "covariate", "process")))
   expect_equal(attr(Process(CP_work)[[2]], 'call_path'),
-               structure(list(occurrence = "AnophelesPlumbeus", covariate = "UKAir", process = "Background"),
+               structure(list(occurrence = "NaiveRandomPresence", covariate = "UKAir", process = "Background"),
                          .Names = c("occurrence", "covariate", "process")))
   expect_equal(attr(Model(CP_work)[[1]], 'call_path'),
                structure(list(occurrence = "UKAnophelesPlumbeus", covariate = "UKAir", process = "Background", model = "RandomForest"),
@@ -29,51 +29,51 @@ test_that('Test call_path in a large number of variations', {
                structure(list(occurrence = "UKAnophelesPlumbeus", covariate = "UKAir", process = "Background", model = "RandomForest", output = "PrintMap"),
                          .Names = c("occurrence", "covariate", "process", "model", "output")))
   expect_equal(attr(Output(CP_work)[[2]], 'call_path'),
-               structure(list(occurrence = "AnophelesPlumbeus", covariate = "UKAir", process = "Background", model = "RandomForest", output = "PrintMap"),
+               structure(list(occurrence = "NaiveRandomPresence", covariate = "UKAir", process = "Background", model = "RandomForest", output = "PrintMap"),
                          .Names = c("occurrence", "covariate", "process", "model", "output")))
                             
-  CP_worka <- workflow(occurrence = Chain(UKAnophelesPlumbeus, AnophelesPlumbeus),
+  CP_worka <- workflow(occurrence = Chain(UKAnophelesPlumbeus, NaiveRandomPresence),
                        covariate  = UKAir,
                        process    = Background(n=70),
                        model      = RandomForest,
                        output     = PrintMap)
   
   expect_equal(attr(Occurrence(CP_worka), 'call_path'),
-               structure(list(occurrence = "Chain(UKAnophelesPlumbeus, AnophelesPlumbeus)"), .Names = "occurrence"))
+               structure(list(occurrence = "Chain(UKAnophelesPlumbeus, NaiveRandomPresence)"), .Names = "occurrence"))
   expect_equal(attr(Process(CP_worka), 'call_path'),
-               structure(list(occurrence = "Chain(UKAnophelesPlumbeus, AnophelesPlumbeus)", covariate = "UKAir", process = "Background"),
+               structure(list(occurrence = "Chain(UKAnophelesPlumbeus, NaiveRandomPresence)", covariate = "UKAir", process = "Background"),
                          .Names = c("occurrence", "covariate", "process")))
   expect_equal(attr(Model(CP_worka), 'call_path'),
-               structure(list(occurrence = "Chain(UKAnophelesPlumbeus, AnophelesPlumbeus)", covariate = "UKAir", process = "Background", model = "RandomForest"),
+               structure(list(occurrence = "Chain(UKAnophelesPlumbeus, NaiveRandomPresence)", covariate = "UKAir", process = "Background", model = "RandomForest"),
                          .Names = c("occurrence", "covariate", "process", "model")))
   expect_equal(attr(Output(CP_worka), 'call_path'),
-               structure(list(occurrence = "Chain(UKAnophelesPlumbeus, AnophelesPlumbeus)", covariate = "UKAir", process = "Background", model = "RandomForest", output = "PrintMap"),
+               structure(list(occurrence = "Chain(UKAnophelesPlumbeus, NaiveRandomPresence)", covariate = "UKAir", process = "Background", model = "RandomForest", output = "PrintMap"),
                          .Names = c("occurrence", "covariate", "process", "model", "output")))
   
   CP_work2 <- workflow(occurrence = UKAnophelesPlumbeus,
-                       covariate  = list(UKBioclim, UKAir),
+                       covariate  = list(NaiveRandomRaster, UKAir),
                        process    = Background(n=70),
                        model      = RandomForest,
                        output     = PrintMap)
   
   expect_equal(attr(Covariate(CP_work2)[[1]], 'call_path'),
-               structure(list(covariate = "UKBioclim"), .Names = "covariate"))
+               structure(list(covariate = "NaiveRandomRaster"), .Names = "covariate"))
   expect_equal(attr(Covariate(CP_work2)[[2]], 'call_path'),
                structure(list(covariate = "UKAir"), .Names = "covariate"))
   expect_equal(attr(Process(CP_work2)[[1]], 'call_path'),
-               structure(list(occurrence = "UKAnophelesPlumbeus", covariate = "UKBioclim", process = "Background"),
+               structure(list(occurrence = "UKAnophelesPlumbeus", covariate = "NaiveRandomRaster", process = "Background"),
                          .Names = c("occurrence", "covariate", "process")))
   expect_equal(attr(Process(CP_work2)[[2]], 'call_path'),
                structure(list(occurrence = "UKAnophelesPlumbeus", covariate = "UKAir", process = "Background"),
                          .Names = c("occurrence", "covariate", "process")))
   expect_equal(attr(Model(CP_work2)[[1]], 'call_path'),
-               structure(list(occurrence = "UKAnophelesPlumbeus", covariate = "UKBioclim", process = "Background", model = "RandomForest"),
+               structure(list(occurrence = "UKAnophelesPlumbeus", covariate = "NaiveRandomRaster", process = "Background", model = "RandomForest"),
                          .Names = c("occurrence", "covariate", "process", "model")))
   expect_equal(attr(Model(CP_work2)[[2]], 'call_path'),
                structure(list(occurrence = "UKAnophelesPlumbeus", covariate = "UKAir", process = "Background", model = "RandomForest"),
                          .Names = c("occurrence", "covariate", "process", "model")))
   expect_equal(attr(Output(CP_work2)[[1]], 'call_path'),
-               structure(list(occurrence = "UKAnophelesPlumbeus", covariate = "UKBioclim", process = "Background", model = "RandomForest", output = "PrintMap"),
+               structure(list(occurrence = "UKAnophelesPlumbeus", covariate = "NaiveRandomRaster", process = "Background", model = "RandomForest", output = "PrintMap"),
                          .Names = c("occurrence", "covariate", "process", "model", "output")))
   expect_equal(attr(Output(CP_work2)[[2]], 'call_path'),
                structure(list(occurrence = "UKAnophelesPlumbeus", covariate = "UKAir", process = "Background", model = "RandomForest", output = "PrintMap"),
@@ -99,77 +99,77 @@ test_that('Test call_path in a large number of variations', {
                          .Names = c("occurrence", "covariate", "process", "model", "output")))
   
   
-  CP_work1 <- workflow(occurrence = Chain(UKAnophelesPlumbeus, AnophelesPlumbeus),
+  CP_work1 <- workflow(occurrence = Chain(UKAnophelesPlumbeus, NaiveRandomPresence),
                        covariate  = UKAir,
                        process    = list(NoProcess, Background(n=70)),
                        model      = RandomForest,
                        output     = PrintMap)
   
   expect_equal(attr(Occurrence(CP_work1), 'call_path'),
-               structure(list(occurrence = "Chain(UKAnophelesPlumbeus, AnophelesPlumbeus)"), .Names = "occurrence"))
+               structure(list(occurrence = "Chain(UKAnophelesPlumbeus, NaiveRandomPresence)"), .Names = "occurrence"))
   expect_equal(attr(Process(CP_work1)[[1]], 'call_path'),
-               structure(list(occurrence = "Chain(UKAnophelesPlumbeus, AnophelesPlumbeus)", covariate = "UKAir", process = "NoProcess"),
+               structure(list(occurrence = "Chain(UKAnophelesPlumbeus, NaiveRandomPresence)", covariate = "UKAir", process = "NoProcess"),
                          .Names = c("occurrence", "covariate","process")))
   expect_equal(attr(Process(CP_work1)[[2]], 'call_path'),
-               structure(list(occurrence = "Chain(UKAnophelesPlumbeus, AnophelesPlumbeus)", covariate = "UKAir", process = "Background"),
+               structure(list(occurrence = "Chain(UKAnophelesPlumbeus, NaiveRandomPresence)", covariate = "UKAir", process = "Background"),
                          .Names = c("occurrence","covariate", "process")))
   expect_equal(attr(Model(CP_work1)[[1]], 'call_path'),
-               structure(list(occurrence = "Chain(UKAnophelesPlumbeus, AnophelesPlumbeus)", covariate = "UKAir", process = "NoProcess", model = "RandomForest"),
+               structure(list(occurrence = "Chain(UKAnophelesPlumbeus, NaiveRandomPresence)", covariate = "UKAir", process = "NoProcess", model = "RandomForest"),
                          .Names = c("occurrence", "covariate", "process", "model")))
   expect_equal(attr(Model(CP_work1)[[2]], 'call_path'),
-               structure(list(occurrence = "Chain(UKAnophelesPlumbeus, AnophelesPlumbeus)", covariate = "UKAir", process = "Background", model = "RandomForest"),
+               structure(list(occurrence = "Chain(UKAnophelesPlumbeus, NaiveRandomPresence)", covariate = "UKAir", process = "Background", model = "RandomForest"),
                          .Names = c("occurrence", "covariate", "process", "model")))
   expect_equal(attr(Output(CP_work1)[[1]], 'call_path'),
-               structure(list(occurrence = "Chain(UKAnophelesPlumbeus, AnophelesPlumbeus)", covariate = "UKAir", process = "NoProcess", model = "RandomForest", output = "PrintMap"),
+               structure(list(occurrence = "Chain(UKAnophelesPlumbeus, NaiveRandomPresence)", covariate = "UKAir", process = "NoProcess", model = "RandomForest", output = "PrintMap"),
                          .Names = c("occurrence", "covariate", "process", "model", "output")))
   expect_equal(attr(Output(CP_work1)[[2]], 'call_path'),
-               structure(list(occurrence = "Chain(UKAnophelesPlumbeus, AnophelesPlumbeus)", covariate = "UKAir", process = "Background", model = "RandomForest", output = "PrintMap"),
+               structure(list(occurrence = "Chain(UKAnophelesPlumbeus, NaiveRandomPresence)", covariate = "UKAir", process = "Background", model = "RandomForest", output = "PrintMap"),
                          .Names = c("occurrence", "covariate", "process", "model", "output")))
   expect_equal(attr(Output(CP_work1)[[1]], 'call_path'),
-               structure(list(occurrence = "Chain(UKAnophelesPlumbeus, AnophelesPlumbeus)", covariate = "UKAir", process = "NoProcess", model = "RandomForest", output = "PrintMap"),
+               structure(list(occurrence = "Chain(UKAnophelesPlumbeus, NaiveRandomPresence)", covariate = "UKAir", process = "NoProcess", model = "RandomForest", output = "PrintMap"),
                          .Names = c("occurrence", "covariate", "process", "model", "output")))
   expect_equal(attr(Output(CP_work1)[[2]], 'call_path'),
-               structure(list(occurrence = "Chain(UKAnophelesPlumbeus, AnophelesPlumbeus)", covariate = "UKAir", process = "Background", model = "RandomForest", output = "PrintMap"),
+               structure(list(occurrence = "Chain(UKAnophelesPlumbeus, NaiveRandomPresence)", covariate = "UKAir", process = "Background", model = "RandomForest", output = "PrintMap"),
                          .Names = c("occurrence", "covariate", "process", "model", "output")))
   
   
 
-  CP_work1a <- workflow(occurrence = Chain(UKAnophelesPlumbeus, AnophelesPlumbeus),
+  CP_work1a <- workflow(occurrence = Chain(UKAnophelesPlumbeus, NaiveRandomPresence),
                         covariate  = UKAir,
                         process    = Chain(NoProcess, Background(n=70)),
                         model      = RandomForest,
                         output     = PrintMap)
   
   expect_equal(attr(Occurrence(CP_work1a), 'call_path'),
-               structure(list(occurrence = "Chain(UKAnophelesPlumbeus, AnophelesPlumbeus)"), .Names = "occurrence"))
+               structure(list(occurrence = "Chain(UKAnophelesPlumbeus, NaiveRandomPresence)"), .Names = "occurrence"))
   expect_equal(attr(Process(CP_work1a), 'call_path'),
-               structure(list(occurrence = "Chain(UKAnophelesPlumbeus, AnophelesPlumbeus)", covariate = "UKAir", process = "Chain(NoProcess, Background)"),
+               structure(list(occurrence = "Chain(UKAnophelesPlumbeus, NaiveRandomPresence)", covariate = "UKAir", process = "Chain(NoProcess, Background)"),
                          .Names = c("occurrence", "covariate","process")))
   expect_equal(attr(Model(CP_work1a), 'call_path'),
-               structure(list(occurrence = "Chain(UKAnophelesPlumbeus, AnophelesPlumbeus)", covariate = "UKAir", process = "Chain(NoProcess, Background)", model = "RandomForest"),
+               structure(list(occurrence = "Chain(UKAnophelesPlumbeus, NaiveRandomPresence)", covariate = "UKAir", process = "Chain(NoProcess, Background)", model = "RandomForest"),
                          .Names = c("occurrence", "covariate", "process", "model")))
   expect_equal(attr(Output(CP_work1a), 'call_path'),
-               structure(list(occurrence = "Chain(UKAnophelesPlumbeus, AnophelesPlumbeus)", covariate = "UKAir", process = "Chain(NoProcess, Background)", model = "RandomForest", output = "PrintMap"),
+               structure(list(occurrence = "Chain(UKAnophelesPlumbeus, NaiveRandomPresence)", covariate = "UKAir", process = "Chain(NoProcess, Background)", model = "RandomForest", output = "PrintMap"),
                          .Names = c("occurrence", "covariate", "process", "model", "output")))
   
 
-  CP_work3 <- workflow(occurrence = Chain(UKAnophelesPlumbeus, AnophelesPlumbeus),
+  CP_work3 <- workflow(occurrence = Chain(UKAnophelesPlumbeus, NaiveRandomPresence),
                        covariate  = UKAir,
                        process    = Chain(NoProcess, Background(n=70)),
                        model      = list(RandomForest, LogisticRegression),
                        output     = PrintMap)
   
   expect_equal(attr(Model(CP_work3)[[1]], 'call_path'),
-               structure(list(occurrence = "Chain(UKAnophelesPlumbeus, AnophelesPlumbeus)", covariate = "UKAir", process = "Chain(NoProcess, Background)", model = "RandomForest"),
+               structure(list(occurrence = "Chain(UKAnophelesPlumbeus, NaiveRandomPresence)", covariate = "UKAir", process = "Chain(NoProcess, Background)", model = "RandomForest"),
                          .Names = c("occurrence", "covariate","process","model")))
   expect_equal(attr(Model(CP_work3)[[2]], 'call_path'),
-               structure(list(occurrence = "Chain(UKAnophelesPlumbeus, AnophelesPlumbeus)", covariate = "UKAir", process = "Chain(NoProcess, Background)", model = "LogisticRegression"),
+               structure(list(occurrence = "Chain(UKAnophelesPlumbeus, NaiveRandomPresence)", covariate = "UKAir", process = "Chain(NoProcess, Background)", model = "LogisticRegression"),
                          .Names = c("occurrence", "covariate","process","model")))
   expect_equal(attr(Output(CP_work3)[[1]], 'call_path'),
-               structure(list(occurrence = "Chain(UKAnophelesPlumbeus, AnophelesPlumbeus)", covariate = "UKAir", process = "Chain(NoProcess, Background)", model = "RandomForest", output = "PrintMap"),
+               structure(list(occurrence = "Chain(UKAnophelesPlumbeus, NaiveRandomPresence)", covariate = "UKAir", process = "Chain(NoProcess, Background)", model = "RandomForest", output = "PrintMap"),
                          .Names = c("occurrence", "covariate", "process", "model", "output")))
   expect_equal(attr(Output(CP_work3)[[2]], 'call_path'),
-               structure(list(occurrence = "Chain(UKAnophelesPlumbeus, AnophelesPlumbeus)", covariate = "UKAir", process = "Chain(NoProcess, Background)", model = "LogisticRegression", output = "PrintMap"),
+               structure(list(occurrence = "Chain(UKAnophelesPlumbeus, NaiveRandomPresence)", covariate = "UKAir", process = "Chain(NoProcess, Background)", model = "LogisticRegression", output = "PrintMap"),
                          .Names = c("occurrence", "covariate", "process", "model", "output")))
   
 
