@@ -7,17 +7,26 @@ test_that('repo modules pass', {
   # Output
   expect_true(x <- zoon:::test_module('https://raw.githubusercontent.com/zoonproject/modules/master/R/PrintMap.R'))
   
-  # Process
+  # Process PO
   expect_true(x <- zoon:::test_module('https://raw.githubusercontent.com/zoonproject/modules/master/R/OneHundredBackground.R'))
   
-  # Model
+  # Process PA
+  expect_true(x <- zoon:::test_module('https://raw.githubusercontent.com/zoonproject/modules/master/R/Crossvalidate.R'))
+  
+  # Model PA
   expect_true(x <- zoon:::test_module('https://raw.githubusercontent.com/zoonproject/modules/master/R/LogisticRegression.R'))
   
+  # Model PB
+  expect_true(x <- zoon:::test_module('https://raw.githubusercontent.com/zoonproject/modules/master/R/MaxLike.R'))
+  
   # Covariate
   expect_true(x <- zoon:::test_module('https://raw.githubusercontent.com/zoonproject/modules/master/R/UKAir.R'))
   
-  # Occurrence
-  expect_true(x <- zoon:::test_module('https://raw.githubusercontent.com/zoonproject/modules/master/R/AnophelesPlumbeus.R'))
+  # Occurrence PO
+  expect_true(x <- zoon:::test_module('https://raw.githubusercontent.com/zoonproject/modules/master/R/CarolinaWrenPO.R'))
+  
+  # Occurrence PA
+  expect_true(x <- zoon:::test_module('https://raw.githubusercontent.com/zoonproject/modules/master/R/CWBZimbabwe.R'))
   
 })
 
